.. image:: images/tsfresh_logo.svg
   :width: 70 %
   :alt: some characteristics of the time series
   :align: center

=======
tsfresh
=======

This is the documentation of **tsfresh**.

tsfresh is a python package.
It automatically calculates a large number of time series characteristics, the so called features.
Further the package contains methods to evaluate the explaining power and importance of such characteristics for
regression or classification tasks.

You can jump right into the package by looking into our :ref:`quick-start-label`.

Contents
========

The following chapters will explain the tsfresh package in detail:

.. toctree::
   :maxdepth: 1

   text/introduction
   text/quick_start
   text/data_formats
   text/sklearn_transformers
   text/list_of_features
   text/feature_extraction_settings
   text/feature_filtering
   text/how_to_add_custom_feature
   text/large_data
   text/tsfresh_on_a_cluster
   text/forecasting
   text/faq
   api/modules
   authors
   license
   changes
   text/how_to_contribute
   text/feature_calculation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Acknowledgements
================

The research and development of TSFRESH was funded in part by the German Federal Ministry of Education and Research
under grant number 01IS14004 (project iPRODICT).
